Changelog
=========

0.5
---

* Added support for configuring task retries policy.
* Dropped support for Python 3.6.

0.4
---

* Included context in unit events.

0.3
---

* Changed topic of generated messages.
* Added headers to extend routing options.
* Fixed publishing of plurals.

0.2
---

* Fixed URL in the message body.

0.1
---

* Initial release.
